//Codec of file is UTF-8
//-----------------------------------------------------------------------
//    Функции вычисления различных числовых характеристик матриц
//
// 
// Составлено по учебнику Алексеева, адаптировано под Scilab 5.5.2
//-----------------------------------------------------------------------

M=[1 2;3 4;5 6;7 8]
[n,m]=size(M) //определяет число строк и столбцов матрицы M

size(M,1) //определяет число строк матрицы
size(M,'r') //то-же самое

size(M,2) //определяет число столбцов матрицы
size(M,'c') //то-же самое

V=[-1 0 3 -2 1 -1 1] //вектор
length(V) //длина вектора

M=[1 2 3;4 5 6] //матрица
length(M) //количество элементов матрицы

V=[-1 0 3 -2 1 -1 1]
sum(V) //сумма элементов вектора

M=[1 2 3;4 5 6;7 8 9]
Y=sum(M) //сумма элементов матрицы

S1=sum(M,1) //сумма элементов матрицы по столбцам
sum(M,'r')  //эквивалентно

S2=sum(M,2) //сумма элементов матрицы по строкам
sum(M,'c')  //эквивалентно

//Частный случай - вычисление скалярного произведения:

a=[1 2 3]
b=[2 0 1]
sum(a.*b)

// prod(X[,fl]) - вычисляет произведение, работает аналогично функции sum

V=[1,2,3]
prod(V) 

M=[1 2 3; 4 5 6; 7 8 9]
prod(M)
p1=prod(M,1)
p2=prod(M,2)

// max(M[,fl]) - вычисляет наибольший элемент в массиве M, имеет необязательный 
// параметр fl; 
// если параметр fl отсутствует, то функция max(M) возвращает максимальный 
// элемент массива M;
// если fl='r', то функция вернет строку максимальных элементов столбцов 
// матрицы M;
// если fl='с', то результатом работы функции будет вектор-столбец, каждый 
// элемент которого равен максимальному элементу соответствующих строк 
// матрицы M;
// функция [x, nom]=max(M[,fl]) вернет значение максимального элемента x 
// и его номер в массиве nom

M=[5 0 3;2 7 1;0 4 9]
max(M)
[x,nom]=max(M)
max(M,'r')
max(M,'c')

// min(M[,fl]) - вычисляет наименьший элемент в массиве M, работает 
// аналогично функции max

A=[5 10 3 2 7 1 25 4 0]
[x,nom]=min(A)

// mean(M[,fl]) - вычисляет среднее значение массива M;
// если M двумерный массив, то: 
// mean(M,1) или mean(M,’r’) определяют среднее значение строк матрицы M, а 
// mean(M,2) или mean(M,’c’) - среднее значение столбцов

M=[9 0 0;0 18 0;0 0 27]
mean(M)
mean(M,1)
mean(M,2)

// median(M[,fl]) - вычисляет медиану массива M (значение, которое делит 
// массив на две части), работает аналогично функции mean

M=[5 0 3;2 7 1;0 4 9]
median(M)
median(M,1)
median(M,2)

// det(M) - вычисляет определитель квадратной матрицы М; определитель или 
// детерминант матрицы - это число, представляющее собой сумму всевозможных 
// перестановок элементов этой матрицы

M=[1 0 2;3 2 1;0 3 1]
det(M)

// rank(M[,tol]) - вычисление ранга матрицы M с точностью tol; ранг матрицы - 
// максимальное число линейнонезависимых строк

rank(M)

// norm(M[,fl]) - вычисление нормы квадратной матрицы М; 
// тип нормы определяется необязательной переменной fl (по умолчанию fl=2);
// функции norm(M) и norm(M,2) эквивалентны и вычисляют вторую норму матрицы М;
// вторая норма матрицы - ее наибольшее сингулярное значение

M=[1 0 2;3 2 1;0 3 1]
norm(M)
norm(M,2)

// первая норма определяется функцией norm(M,1); 
// функции norm(M,’inf’) и norm(M,’fro’) вычисляют соответственно бесконечную 
// и евклидову нормы;
// первая норма матрицы - наибольшая сумма по столбцам;
// бесконечная норма - наибольшая сумма по строкам;
// евклидова норма - корень из суммы квадратов всех элементов матрицы

M=[1 0 2;3 2 1;0 3 1]
norm(M,1)
norm(M,'inf')
norm(M,'fro')

// если V вектор, то результатом работы функции norm(V,1) будет сумма модулей 
// всех элементов вектора V; с помощью функции norm(V,2) можно вычислить 
// модуль вектора V; значение norm(V,’inf’) равно модулю максимального 
// элемента по модулю

X=[5 -3 4 -1 2]
norm(X,1)
sum(abs(X)) //то-же, что и norm(X,1)

norm(X,2)
sqrt(sum(X.^2)) //то-же, что и norm(X,2)

norm(X,'inf')
max(abs(X)) //то-же, что и norm(X,'inf')

// сond(M) - вычисляет число обусловленности матрицы М по второй норме;
// число обусловленности равно произведению нормы исходной матрицы на норму 
// обратной

A=[5 7 6 5;7 10 8 7;6 8 10 9;5 7 9 10]
cond(A)


clear
