//Codec of file is UTF-8
//-----------------------------------------------------------------------
//            Функции для решения задач линейной алгебры
//
// 
// Составлено по учебнику Алексеева, проверено в SciLab 5.5.2
//-----------------------------------------------------------------------

// spec(M) - вычисляет собственные значения и собственные векторы квадратной 
// матрицы M; любой ненулевой вектор x, принадлежащий некоторому векторному 
// пространству, для которого Ax=Lx, где L - некоторое число, называется 
// собственным вектором матрицы А, L - соответствующим ему собственным
// значением

M=[3 -2;-4 1]
spec(M) //собственные числа матрицы

// Х - собственные векторы, соответствующие собственным значениям 
// из матрицы Y.
[X,Y]=spec(M)

// inv(A) - вычисляет матрицу, обратную к A

A=[1 2 3 5; 0 1 3 2; 4 2 1 1; 2 3 0 1]
inv(A)

// Проверка - при умножении обратной матрицы на исходную должны получить 
// единичную матрицу (реально же - близкую к единичной)

inv(A)*A

// При попытке обратить вырожденную матрицу (определитель равен или близок 
// к нулю) получим сообщение об ошибке

//B=[1 2 3;1 4 5;1 6 7]
//inv(B) - выдаст ошибку

// pinv(A[,tol]) - вычисляет псевдообратную матрицу для матрицы A с точностью 
// tol (необязательный параметр); если для матрицы pinv(A[,tol])= X выполняется 
// условие AXA=A, XAX=X, а матрицы ХА и AХ эрмитовы, то вычисляемая матрица 
// Х псевдообратная к А. Вычисление базируется на методе сингулярного разложения
// и все сингулярные значения матрицы меньшие tol приравниваются нулю

pinv(A)

// linsolve(A,b) - решает систему линейных алгебраических уравнений вида 
// Ax+b=0

// решим систему линейных уравнений 
//
//{x1+2x2–7=0; x1+x2–6=0}; 
//
// свободные коэффициенты вводятся как вектор–столбец и с учетом знаков

A=[1 2;1 1];b=[-7;-6]
x=linsolve(A,b)

// результатом операции A*x+b является вектор достаточно близкий к нулю, 
// это значит, что система решена верно

A*x+b

// Если система не имеет решений, SciLab выдаст пустой массив [] и 
// предупреждение; например, система 
// {x1+x2-1=0; x1+x2-3=0} 
// не имеет решений
A=[1 1;1 1]; b=[-1;-3];
linsolve(A,b)

// в случае, когда система имеет бесконечное множество решений, SciLab 
// выдаст одно из них ({3x1-x2-1=0; 6x1-2x2-2=0}): 

A=[3 -1;6 -2]
b=[-1;-2]
x=linsolve(A,b)

// rref(A) - осуществляет приведение матрицы A к треугольной форме, используя 
// метод исключения Гаусса

A=[3 -2 1 5; 6 -4 2 7; 9 -6 3 12]
rref(A)

// lu(М) - выполняет треугольное разложение матрицы М;
// L и U - нижняя и верхняя треугольные матрицы; называется LU-разложением;

A=[2 -1 5;3 2 -5;1 1 -2]
[L,U]=lu(A)

LU=L*U

// qr(М) - выполняет разложение матрицы М на ортогональную и верхнюю треугольную 
// матрицы; Q - ортогональная, R - верхняя треугольная матрицы; 
// называется QR-разложением;

[Q,R]=qr(A)
Q*R

// svd(М) - выполняет сингулярное разложение матрицы М размером n*m; результатом  
// работы функции может быть либо сингулярное разложение, либо вектор, 
// содержащий сингулярные значения матрицы;
// U и V - m*m и n*n ортогональные матрицы, а S - диагональная матрица, на 
// диагонали которой расположены сингулярные числа матрицы М

[U,S,V]=svd(A)
U*S*V'

s=svd(A)

// kernel(М[,tol[,fl]]) - определение ядра матрицы М, параметры tol и fl 
// являются не обязательными; первый задает точность вычислений, второй - 
// используемый при вычислении алгоритм и принимает значения 'qr' или 'svd';
// ядро матрицы - это множество векторов Х; поиск ядра матрицы сводится к 
// решению однородной системы линейных уравнений АХ=0; если при вызове 
// функции X=kernel(A) матрица окажется не пустой, то действительно AX=0;

A=[4 1 -3 -1;2 3 1 -5;1 -2 -2 3]
X=kernel(A)


clear
