//Codec of file is UTF-8
//-----------------------------------------------------------------------
//         Решение систем линейных алгебраических уравнений
//
// 
// Составлено по учебнику Алексеева, проверено в Scilab 5.5.2
//-----------------------------------------------------------------------

// Решим СЛАУ при помощи правила Крамера:
//
//         2x1 +  x2 - 5x3 + x4 = 8,
//         x1 - 3x2 - 6x4 = 9,
//         2x2 - x3 + 2x4 = -5,
//         x1 + 4x2 - 7x3 + 6x4 = 0
//
// Правило Крамера заключается в следующем. Если определитель detA матрицы 
// системы из n уравнений с n неизвестными Ax=b отличен от нуля, то система 
// имеет единственное решение x1,x2,...,xn, определяемое по формулам 
// Крамера xi=Di/detA, где Di - определитель матрицы, полученной из матрицы 
// системы А заменой i-го столбца столбцом свободных членов b.

A=[2 1 -5 1;1 -3 0 -6;0 2 -1 2;1 4 -7 6] //матрица коэффициентов
b=[8;9;-5;0]  //вектор свободных коэффициентов

A1=A;A1(:,1)=b; //первая вспомогательная матрица
A2=A;A2(:,2)=b; //вторая вспомогательная матрица
A3=A;A3(:,3)=b; //третья вспомогательная матрица
A4=A;A4(:,4)=b; //четвертая вспомогательная матрица

D=det(A); //главный определитель

//определители вспомогательных матриц:
d(1)=det(A1); d(2)=det(A2); d(3)=det(A3); d(4)=det(A4);

x=d/D //вектор неизвестных

P=A*x-b //проверка (должно быть близко к нулю)

// Метод обратной матрицы: для системы из n линейных уравнений с n 
// неизвестными Ax=b при условии, что определитель матрицы А не равен нулю, 
// единственное решение можно представить в виде x=(A^-1)*b. 

x=inv(A)*b //решение системы

// Решим систему линейных уравнений методом Гаусса:
//
//                      2x1 - x2 + x3 = 0,
//                      3x1 + 2x2 - 5x3 = 1,
//                      x1 + 3x2 - 2x3 = 4.
//
// Решение системы линейных уравнений при помощи метода Гаусса основывается 
// на том, что от заданной системы переходят к эквивалентной системе, которая 
// решается проще, чем исходная система. Метод Гаусса состоит из двух этапов. 
// Первый этап - это прямой ход, в результате которого расширенная матрица 
// системы путем элементарных преобразований (перестановка уравнений системы,
// умножение уравнений на число, отличное от нуля и сложение уравнений) 
// приводится к ступенчатому виду. На втором этапе обратный ход) ступенчатую 
// матрицу преобразовывают так, чтобы в первых n столбцах получилась единичная 
// матрица. Последний (n+1) столбец этой матрицы содержит решение системы. 

// матрица и вектор свободных коэффициентов системы:
A=[2 -1 1;3 2 -5;1 3 -2]
b=[0;1;4]

// приведение расширенной матрицы к треугольному виду:
C=rref([A b]);

// определение размерности расширенной матрицы:
[n,m]=size(C);  //m - номер последнего столбца матрицы С

// выделение последнего столбца из матрицы С (решение системы):
x=C(:,m)  

A*x-b //проверка (должно быть близко к нулю)

clear

