//Codec of this file is UTF-8
//-----------------------------------------------------------------------
//                      Решение задач оптимизации
//
// 
// Составлено по учебнику Алексеева, адаптировано под SciLab 5.5.2
//-----------------------------------------------------------------------
//
// Использует атом Quapro (требуется его установка)
//-----------------------------------------------------------------------

// Функция fi, в которой будет формироваться функция f и ее производная g 
function [f,g,ind]=fi(x,ind)
    // Функция f, минимум которой ищется
    f=x^4+3*x^3-13*x^2-6*x+26;
    // Функция g - производная от функции f
    g=4*x^3+9*x^2-26*x-6;
endfunction

// Начальное приближение точки минимума
y0=-2;

// Для поиска точки минимума (xmin) и значения функции (fmin) в ней - 
// вызов функции optim
[fmin,xmin]=optim(fi,y0);

printf("xmin = %f; fmin = %f\n", xmin, fmin);

clear;

// Начальное приближение x0
x0=[-2;2];

//Функция Розенброка
function y=gg(x)
    // Обратите внимание, здесь x - массив из двух неизвестных
    y=100*(x(2)-x(1)^2)^2+(1-x(1))^2;
endfunction

//Формирование функции cst, возвращающей функцию Розенброка и ее градиент
function [f,g,ind]=cst(x,ind)
    f=gg(x);
    g=numderivative(gg,x); //вместо устаревшей numdiff
endfunction

// Вызов функции optim
[f,xopt]=optim(cst,x0);

printf("x0 = %f; xopt = %f; f = %e\n", x0, xopt, f);

clear;

// Для решения задач линейного программирования предназначена функция 
// linpro (требуется атом Quapro) следующей структуры:
//
//                          [x,kl,f]=linpro(с,A,b[,ci,cs][,k][,x0])
//
// Здесь с - вектор-столбец коэффициентов при неизвестных функции цели, 
// длина вектора (n) совпадает с количеством неизвестных x;
// A - матрица при неизвестных из левой части системы ограничений; 
// количество строк матрицы равно количеству ограничений m, а количество 
// столбцов совпадает с количеством неизвестных n;
// b - вектор-столбец, содержит свободные члены системы ограничений, 
// длина вектора m;
// ci - вектор-столбец размерностью n, содержит нижнюю границу переменных; 
// если таковая отсутствует, указывают [];
// cs - вектор-столбец длиной n, содержит верхнюю границу переменных; если 
// таковая отсутствует, указывают [];
// k - целочисленная переменная используется, если в систему ограничений 
// кроме неравенств входят и равенства; в матрице они будут находиться в 
// k первых строках, оставшиеся l строк займут неравенства (т.е. m=k+l);
// x0 - вектор-столбец начальных приближений длиной n.
//
// Функция linpro возвращает массив неизвестных x, минимальное значение 
// функции f и массив множителей Лагранжа kl.

// ЗАДАЧА. Найти такие значения переменных x1, x2, x3 и x4 при которых 
// функция цели L
//
//                      L = - x2 - 2x3 + x4
//
// достигает своего минимального значения и удовлетворяются ограничения
//
//                      3x1 - x2 <= 2
//                      x2 - 2x3 <= -1
//                      4x3 - x4 <= 3
//                      5x1 + x4 >= 6
//                      x1 >= 0, x2 >= 0, x3 >= 0, x4 >= 0
//
// Обратите внимание, что в четвертом ограничении присутствует знак >=
// Для приведения системы ограничений к нужному виду необходимо четвертое 
// уравнение умножить на -1.

c=[0;-1;-2;1];
A=[3 -1 0 0; 0 1 -2 0; 0 0 4 -1; -5 0 0 -1];
b=[2;-1;3;-6];
ci=[0;0;0;0];
[x,kl,f]=linpro(c,A,b,ci,[]);
printf("f = %f\n",f);
for i=1:4
    printf("x(%d)=%f\n",i,x(i));
end

clear
